@@ -217,4 +217,59 @@ sub ok
 }
 
 
+# These two subs lifted directly from MLDBM.pm
+#
+sub _compare {
+    use vars qw(%compared);
+    local %compared;
+    return _cmp(@_);
+}
+
+sub _cmp {
+    my($a, $b) = @_;
+
+    # catch circular loops
+    return(1) if $compared{$a.'&*&*&*&*&*'.$b}++;
+#    print "$a $b\n";
+#    print &Data::Dumper::Dumper($a, $b);
+
+    if(ref($a) and ref($a) eq ref($b)) {
+	if(eval { @$a }) {
+#	    print "HERE ".@$a." ".@$b."\n";
+	    @$a == @$b or return 0;
+#	    print @$a, ' ', @$b, "\n";
+#	    print "HERE2\n";
+
+	    for(0..@$a-1) {
+		&_cmp($a->[$_], $b->[$_]) or return 0;
+	    }
+	} elsif(eval { %$a }) {
+	    keys %$a == keys %$b or return 0;
+	    for (keys %$a) {
+		&_cmp($a->{$_}, $b->{$_}) or return 0;
+	    }
+	} elsif(eval { $$a }) {
+	    &_cmp($$a, $$b) or return 0;
+	} else {
+	    die("data $a $b not handled");
+	}
+	return 1;
+    } elsif(! ref($a) and ! ref($b)) {
+	return ($a eq $b);
+    } else {
+	return 0;
+    }
+
+}
+
+sub fillout
+{
+    my $var = shift ;
+    my $length = shift ;
+    my $pad = shift || " " ;
+    my $template = $pad x $length ;
+    substr($template, 0, length($var)) = $var ;
+    return $template ;
+}
+
 1;
